
### 0.9.1

```{rubric} Features
```
* added batchsize for {func}`~rapids_singlecell.tl.embedding_density` {pr}`67` {smaller}`S Dicks`
* adds subclustering and brings {func}`~rapids_singlecell.tl.leiden` and {func}`~rapids_singlecell.tl.louvain` closer to feature parity with [`scanpy`](https://scanpy.readthedocs.io/en/stable/api/index.html) {pr}`68` {smaller}`S Dicks`

```{rubric} Misc
```
* Can now be installed against CUDA11 and CUDA12 with pip {pr}`72` {smaller}`S Dicks`
